/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice.resolveengine.excludes;

import org.gradle.api.artifacts.ModuleIdentifier;

/**
 * Excludes any module that has a module id matching the one specified.
 * Does not exclude artifacts.
 */
class ModuleIdExcludeSpec extends AbstractModuleExclusion {
    final ModuleIdentifier moduleId;

    public ModuleIdExcludeSpec(ModuleIdentifier id) {
        this.moduleId = id;
    }

    @Override
    public String toString() {
        return "{module-id " + moduleId + "}";
    }

    @Override
    protected boolean doEquals(Object o) {
        ModuleIdExcludeSpec other = (ModuleIdExcludeSpec) o;
        return moduleId.equals(other.moduleId);
    }

    @Override
    protected int doHashCode() {
        return moduleId.hashCode();
    }

    @Override
    protected boolean doExcludesSameModulesAs(AbstractModuleExclusion other) {
        ModuleIdExcludeSpec moduleIdExcludeSpec = (ModuleIdExcludeSpec) other;
        return moduleId.equals(moduleIdExcludeSpec.moduleId);
    }

    public boolean excludeModule(ModuleIdentifier module) {
        return module.equals(moduleId);
    }
}
